<?php
/**
 *  functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * * @package peccular Premium
 */
$query='';
if ( ! function_exists( 'peccular_lite_setup' ) ) :
    /**
     * Sets up theme defaults and registers support for various WordPress features.
     *
     * Note that this function is hooked into the after_setup_theme hook, which
     * runs before the init hook. The init hook is too late for some features, such
     * as indicating support for post thumbnails.
     */
    function peccular_lite_setup() {
        define( 'MTS_THEME_VERSION', '2.0.6' );
        /*
         * Make theme available for translation.
         * Translations can be filed in the /languages/ directory.
         * If you're building a theme based on publishable, use a find and replace
         * to change 'peccular Premium' to the name of your theme in all the template files.
         */
        load_theme_textdomain( 'peccular Premium', get_template_directory() . '/languages' );

        // Add default posts and comments RSS feed links to head.
        add_theme_support( 'automatic-feed-links' );

        /*
         * Let WordPress manage the document title.
         * By adding theme support, we declare that this theme does not use a
         * hard-coded <title> tag in the document head, and expect WordPress to
         * provide it for us.
         */
        add_theme_support( 'title-tag' );

        /*
         * Enable support for Post Thumbnails on posts and pages.
         *
         * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
         */
        add_theme_support( 'post-thumbnails' );
        set_post_thumbnail_size( 150, 150, true );
        add_image_size( 'peccular Premium-related', 200, 125, true ); //related

        // This theme uses wp_nav_menu() in one location.
        register_nav_menus( array(
            'primary' => esc_html__( 'Primary Menu', 'peccular Premium' ),
        ) );


        // This theme uses wp_nav_menu() in one location.
        register_nav_menus( array(
            'topmenu' => esc_html__( 'Top Menu', 'peccular Premium' ),
        ) );

        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         */
        add_theme_support( 'html5', array(
            'comment-form',
            'comment-list',
            'gallery',
            'caption',
        ) );

        if ( peccular_lite_is_wc_active() ) {
            add_theme_support( 'woocommerce' );
        }
        
        // Set up the WordPress core custom background feature.
        add_theme_support( 'custom-background', apply_filters( 'peccular_lite_custom_background_args', array(
          'default-color' => '#000',
          'default-image' => '',
      ) ) );
    }
endif;
add_action( 'after_setup_theme', 'peccular_lite_setup' );

function peccular_lite_content_width() {
    $GLOBALS['content_width'] = apply_filters( 'peccular_lite_content_width', 678 );
}
add_action( 'after_setup_theme', 'peccular_lite_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function peccular_lite_widgets_init() {
    register_sidebar( array(
        'name'          => esc_html__( 'Sidebar', 'peccular Premium' ),
        'id'            => 'sidebar',
        'description'   => '',
        'before_widget' => '<div id="%1$s" class="widget %2$s  wow bounceInUp">',
        'after_widget'  => '</div>',
        'before_title'  => '<h4 class="widget-title"> <svg xmlns="http://www.w3.org/2000/svg" width="334.087" height="51" viewBox="0 0 334.087 51">
  <path id="Path_82" data-name="Path 82" d="M337.6,0h-224.9c-3.764,0-6.815,2.686-6.815,6V45c0,3.314,3.051,6,6.815,6H439.827s2.75-8.44-16.285-14.764-36.7-1.631-59.853-10.531S341.362,0,337.6,0Z" transform="translate(-105.878)" fill="#fe8532"/>
</svg>',
        'after_title'   => '</h4>',
    ) );

    /*// Header Ad sidebar
    register_sidebar(array(
        'name' => __('Header Ad', 'peccular Premium'),
        'description'   => __( '728x90 Ad Area', 'peccular Premium' ),
        'id' => 'widget-header',
        'before_widget' => '<div id="%1$s" class="widget-header">',
        'after_widget' => '</div>',
        'before_title' => '<h3 class="widget-title">',
        'after_title' => '</h3>',
    ));*/
    
    // Shop side bar
    register_sidebar( array(
        'name'          => esc_html__( 'Shop Sidebar', 'peccular Premium' ),
        'id'            => 'peccular-shop-sidebar',
        'description'   => __( 'Add widgets here to appear in your sidebar of shop page.', 'peccular Premium' ),
        'before_widget' => '<aside id="%1$s" class="widget %2$s wow bounceInUp">',
        'after_widget'  => '</aside>',
        'before_title'  => '<h4 class="widget-title"> <svg xmlns="http://www.w3.org/2000/svg" width="334.087" height="51" viewBox="0 0 334.087 51">
  <path id="Path_82" data-name="Path 82" d="M337.6,0h-224.9c-3.764,0-6.815,2.686-6.815,6V45c0,3.314,3.051,6,6.815,6H439.827s2.75-8.44-16.285-14.764-36.7-1.631-59.853-10.531S341.362,0,337.6,0Z" transform="translate(-105.878)" fill="#fe8532"/>
</svg>',
        'after_title'   => '</h4>',
    ) );
    // Blog side bar
    register_sidebar( array(
        'name'          => esc_html__( 'Blog Sidebar', 'peccular Premium' ),
        'id'            => 'peccular-blog-sidebar',
        'description'   => __( 'Add widgets here to appear in your sidebar of blog page.', 'peccular Premium' ),
        'before_widget' => '<aside id="%1$s" class="widget %2$s  wow bounceInUp">',
        'after_widget'  => '</aside>',
        'before_title'  => '<h4 class="widget-title"> <svg xmlns="http://www.w3.org/2000/svg" width="334.087" height="51" viewBox="0 0 334.087 51">
  <path id="Path_82" data-name="Path 82" d="M337.6,0h-224.9c-3.764,0-6.815,2.686-6.815,6V45c0,3.314,3.051,6,6.815,6H439.827s2.75-8.44-16.285-14.764-36.7-1.631-59.853-10.531S341.362,0,337.6,0Z" transform="translate(-105.878)" fill="#fe8532"/>
</svg> ',
        'after_title'   => '</h4>',
    ) );


   // Gtranslate widge top bar
    register_sidebar( array(
        'name'          => esc_html__( 'Language Translate Widge', 'peccular Premium' ),
        'id'            => 'peccular-gtranslate-sidebar',
        'description'   => __( 'Add Language Translate.', 'peccular Premium' ),
        'before_widget' => '<aside id="%1$s" class="widget %2$s  wow bounceInUp">',
        'after_widget'  => '</aside>',
        'before_title'  => '<h4 class="widget-title"> <svg xmlns="http://www.w3.org/2000/svg" width="334.087" height="51" viewBox="0 0 334.087 51">
  <path id="Path_82" data-name="Path 82" d="M337.6,0h-224.9c-3.764,0-6.815,2.686-6.815,6V45c0,3.314,3.051,6,6.815,6H439.827s2.75-8.44-16.285-14.764-36.7-1.631-59.853-10.531S341.362,0,337.6,0Z" transform="translate(-105.878)" fill="#fe8532"/>
</svg>',
        'after_title'   => '</h4>',
    ) );

        // Single post side bar
    register_sidebar( array(
        'name'          => esc_html__( 'Single Post Sidebar', 'peccular Premium' ),
        'id'            => 'peccular-singlepost-sidebar',
        'description'   => __( 'Add widgets here to appear in your sidebar of single post page.', 'peccular Premium' ),
        'before_widget' => '<aside id="%1$s" class="widget %2$s  wow bounceInUp">',
        'after_widget'  => '</aside>',
        'before_title'  => '<h4 class="widget-title"> <svg xmlns="http://www.w3.org/2000/svg" width="334.087" height="51" viewBox="0 0 334.087 51">
  <path id="Path_82" data-name="Path 82" d="M337.6,0h-224.9c-3.764,0-6.815,2.686-6.815,6V45c0,3.314,3.051,6,6.815,6H439.827s2.75-8.44-16.285-14.764-36.7-1.631-59.853-10.531S341.362,0,337.6,0Z" transform="translate(-105.878)" fill="#fe8532"/>
</svg>',
        'after_title'   => '</h4>',
    ) );

 
    // Services side bar
    register_sidebar( array(
        'name'          => esc_html__( 'Service Sidebar', 'peccular Premium' ),
        'id'            => 'peccular-service-sidebar',
        'description'   => __( 'Add widgets here to appear in your sidebar of services page.', 'peccular Premium' ),
        'before_widget' => '<aside id="%1$s" class="widget %2$s  wow bounceInUp">',
        'after_widget'  => '</aside>',
        'before_title'  => '<h4 class="widget-title"> <svg xmlns="http://www.w3.org/2000/svg" width="334.087" height="51" viewBox="0 0 334.087 51">
  <path id="Path_82" data-name="Path 82" d="M337.6,0h-224.9c-3.764,0-6.815,2.686-6.815,6V45c0,3.314,3.051,6,6.815,6H439.827s2.75-8.44-16.285-14.764-36.7-1.631-59.853-10.531S341.362,0,337.6,0Z" transform="translate(-105.878)" fill="#fe8532"/>
</svg>',
        'after_title'   => '</h4>',
    ) );

        // Courses side bar
    register_sidebar( array(
        'name'          => esc_html__( 'Courses Sidebar', 'peccular Premium' ),
        'id'            => 'peccular-courses-sidebar',
        'description'   => __( 'Add widgets here to appear in your sidebar of courses page.', 'peccular Premium' ),
        'before_widget' => '<aside id="%1$s" class="widget %2$s  wow bounceInUp">',
        'after_widget'  => '</aside>',
        'before_title'  => '<h4 class="widget-title"> <svg xmlns="http://www.w3.org/2000/svg" width="334.087" height="51" viewBox="0 0 334.087 51">
  <path id="Path_82" data-name="Path 82" d="M337.6,0h-224.9c-3.764,0-6.815,2.686-6.815,6V45c0,3.314,3.051,6,6.815,6H439.827s2.75-8.44-16.285-14.764-36.7-1.631-59.853-10.531S341.362,0,337.6,0Z" transform="translate(-105.878)" fill="#fe8532"/>
</svg>',
        'after_title'   => '</h4>',
    ) );

    // FOOTER ONE WIDGET SIDEBAR
    register_sidebar( array(
        'name'          => esc_html__( 'Footer One', 'peccular Premium' ),
        'id'            => 'peccular-footer1',
        'description'   => __( 'Add widgets here to appear in your Footer.', 'peccular Premium' ),
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget'  => '</aside>',
        'before_title'  => '<h4 class="widget-title">',
        'after_title'   => '</h4>',
    ) );
    // FOOTER TWO WIDGET SIDEBAR
    register_sidebar( array(
        'name'          => esc_html__( 'Footer Two', 'peccular Premium' ),
        'id'            => 'peccular-footer2',
        'description'   => __( 'Add widgets here to appear in your Footer.', 'peccular Premium' ),
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget'  => '</aside>',
        'before_title'  => '<h4 class="widget-title">',
        'after_title'   => '</h4>',
    ) );
    // FOOTER THREE WIDGET SIDEBAR
    register_sidebar( array(
        'name'          => esc_html__( 'Footer Three', 'peccular Premium' ),
        'id'            => 'peccular-footer3',
        'description'   => __( 'Add widgets here to appear in your Footer.', 'peccular Premium' ),
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget'  => '</aside>',
        'before_title'  => '<h4 class="widget-title">',
        'after_title'   => '</h4>',
    ) );
    // FOOTER FOUR WIDGET SIDEBAR
    register_sidebar( array(
        'name'          => esc_html__( 'Footer Four', 'peccular Premium' ),
        'id'            => 'peccular-footer4',
        'description'   => __( 'Add widgets here to appear in your Footer.', 'peccular Premium' ),
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget'  => '</aside>',
        'before_title'  => '<h4 class="widget-title">',
        'after_title'   => '</h4>',
    ) );
     // FOOTER FIVE WIDGET SIDEBAR
    // register_sidebar( array(
    //     'name'          => esc_html__( 'Footer Five', 'peccular Premium' ),
    //     'id'            => 'peccular-footer5',
    //     'description'   => __( 'Add widgets here to appear in your Footer.', 'peccular Premium' ),
    //     'before_widget' => '<aside id="%1$s" class="widget %2$s">',
    //     'after_widget'  => '</aside>',
    //     'before_title'  => '<h4 class="widget-title">',
    //     'after_title'   => '</h4>',
    // ) ); 

    if ( peccular_lite_is_wc_active() ) {
        // Register WooCommerce Shop and Single Product Sidebar
        register_sidebar( array(
            'name' => __('Shop Page Sidebar', 'peccular Premium' ),
            'description'   => __( 'Appears on Shop main page and product archive pages.', 'peccular Premium' ),
            'id' => 'shop-sidebar',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h4 class="widget-title">',
            'after_title' => '</h4>',
        ) );
        register_sidebar( array(
            'name' => __('Single Product Sidebar', 'peccular Premium' ),
            'description'   => __( 'Appears on single product pages.', 'peccular Premium' ),
            'id' => 'product-sidebar',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget' => '</div>',
            'before_title' => '<h4 class="widget-title">',
            'after_title' => '</h4>',
        ) );
    }
}
add_action( 'widgets_init', 'peccular_lite_widgets_init' );

require_once get_template_directory() . '/functions/cr.php';
function enqueue_custom_scripts() {
    // Register and enqueue your custom JavaScript file
    wp_enqueue_script('custom-script', get_template_directory_uri() . '/path/to/your/custom-script.js', array(), null, true);
}
add_action('wp_enqueue_scripts', 'enqueue_custom_scripts');
wp_enqueue_script('custom-script', get_template_directory_uri() . '/js/custom-script.js', array(), null, true);

function peccular_lite_custom_sidebar() {
    // Default sidebar.
    $sidebar = 'sidebar';

    // Woocommerce.
    if ( peccular_lite_is_wc_active() ) {
        if ( is_shop() || is_product_category() ) {
            $sidebar = 'shop-sidebar';
        }
        if ( is_product() ) {
            $sidebar = 'product-sidebar';
        }
    }

    return $sidebar;
}

/**
 * Enqueue scripts and styles.
 */
function peccular_lite_scripts() {
    wp_enqueue_style( 'peccular Premium-style', get_stylesheet_uri() );

    $handle = 'peccular Premium-style';

    // WooCommerce
    if ( peccular_lite_is_wc_active() ) {
        if ( is_woocommerce() || is_cart() || is_checkout() ) {
            wp_enqueue_style( 'woocommerce', get_template_directory_uri() . '/css/woocommerce2.css' );
            $handle = 'woocommerce';
        }
    }

    wp_enqueue_script( 'smoothscroll', get_template_directory_uri() . '/js/SmoothScroll.js', array(), '20160809', false );
    wp_enqueue_script( 'jquery-nav', get_template_directory_uri() . '/js/jquery.nav.js', array('jquery'), '20160903', true );
    wp_enqueue_script( 'jquery-bxslider', get_template_directory_uri() . '/js/jquery.bxslider.js', array('jquery'), '4.1.2', true );
     wp_enqueue_script( 'isotope-pkgd', get_template_directory_uri() . '/js/isotope.pkgd.js', array('jquery', 'imagesloaded' ), '20150903', true );
    wp_enqueue_script( 'nivo-lightbox', get_template_directory_uri() . '/js/nivo-lightbox.js', array('jquery'), '20150903', true );
    wp_enqueue_script( 'superfish', get_template_directory_uri() . '/js/superfish.js', array('jquery'), '20150903', true );
    wp_enqueue_script( 'jquery-stellar', get_template_directory_uri() . '/js/jquery.stellar.js', array('imagesloaded'), '20150903', false ); 

    wp_enqueue_script( 'owl-carousel', get_template_directory_uri() . '/js/owl.carousel.js', array('jquery'), '1.3.3', true );

    wp_enqueue_script( 'wow', get_template_directory_uri() . '/js/wow.js', array('jquery'), '20150903', true );
    wp_enqueue_script( 'odometer', get_template_directory_uri() . '/js/odometer.js', array('jquery'), '20150903', true );
    wp_enqueue_script( 'waypoint', get_template_directory_uri() . '/js/waypoint.js', array('jquery'), '20150903', true );
    wp_enqueue_script( 'total-custom', get_template_directory_uri() . '/js/total-custom.js', array('jquery'), '20150903', true );
    wp_enqueue_script('slider', get_template_directory_uri().'/js/slider.js', array(), '1.1', true);
    wp_localize_script( 'total-custom', 'total_localize', array('template_path' => get_template_directory_uri() ));

  // wp_enqueue_script('jquery-3-3-1-min', get_template_directory_uri().'/js/jquery-3.3.1.min.js', array(), '1.1', true);
    //  wp_enqueue_script( 'jquery-3-1-1-slim-min', get_template_directory_uri() . '/js/jquery-3.1.1.slim.min.js', array('jquery'), '20150903', true );
      wp_enqueue_script( 'jquery-colorbox', get_template_directory_uri() . '/js/jquery.colorbox.js', array(), '20160809', false );

    wp_enqueue_style( 'bxslider', get_template_directory_uri() . '/css/jquery.bxslider.css', array(), '4.1.2' );
    wp_enqueue_style( 'colorbox-popup', get_template_directory_uri() . '/css/colorbox.css', array(), '4.1.2' );
    wp_enqueue_style( 'animate', get_template_directory_uri() . '/css/animate.css', array(), '1.0' );
    wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome.css', array(), '4.4.0' );
  

    wp_enqueue_style( 'owl-carousel', get_template_directory_uri() . '/css/owl.carousel.css', array(), '1.3.3' );
    wp_enqueue_style( 'owl-theme', get_template_directory_uri() . '/css/owl.theme.css', array(), '1.3.3' );
        wp_enqueue_style( 'nivo-lightbox', get_template_directory_uri() . '/css/nivo-lightbox.css', array(), '1.3.3' );
    wp_enqueue_style( 'superfish', get_template_directory_uri() . '/css/superfish.css', array(), '1.3.3' );

     wp_enqueue_style( 'docs-theme-min', get_template_directory_uri() . '/css/docss.theme.min.css', array(), '1.3.3' );
        wp_enqueue_style( 'owl-carousel-min', get_template_directory_uri() . '/css/owl.carousel.min.css', array(), '1.3.3' );
        wp_enqueue_style( 'owl-theme-default-min', get_template_directory_uri() . '/css/owl.theme.default.min.css', array(), '1.3.3' );
   

    //wp_enqueue_script('owl-carousel-min', get_template_directory_uri().'/js/owl.carousel.min.js', array(), '1.1', true);

  // wp_enqueue_style( 'total-style', get_stylesheet_uri(), array( 'bxslider', 'animate', 'font-awesome', 'owl-carousel', 'owl-theme', 'nivo-lightbox', 'superfish'), '1.0' );
  // wp_enqueue_style( 'total-fonts', total_fonts_url(), array(), null );
   // wp_enqueue_script('script', get_template_directory_uri().'/js/script.js', array(), '1.1', true);
// extra for header
  
   wp_enqueue_style( 'templete', get_template_directory_uri() . '/css-new/templete.css', array(), '1.3.3' );

// extra for header

wp_enqueue_script( 'main', get_template_directory_uri() . '/js/main.js', array('jquery'), '20150903', true );
 wp_enqueue_style( 'style-min', get_template_directory_uri() . '/css/style.min.css', array(), '1.3.3' );

 wp_enqueue_style( 'swiper-min', get_template_directory_uri() . '/css/swiper.min.css', array(), '1.3.3' );
 
 wp_enqueue_script( 'swiper', get_template_directory_uri() . '/js/swiper.min.js', array('jquery'), '20150903', true );
 wp_enqueue_script( 'sliderscript', get_template_directory_uri() . '/js/sliderscript.js', array('jquery'), '20150903', true );

 
// team popup js
 wp_enqueue_script( 'teampopup', get_template_directory_uri() . '/js/teampopup.js', array('jquery'), '20150903', true );


// gallery pop up

 wp_enqueue_style( 'main', get_template_directory_uri() . '/css/gallery/main.css', array(), '1.3.3' );
  wp_enqueue_style( 'lightgallery', get_template_directory_uri() . '/css/gallery/lightgallery.css', array(), '1.3.3' );
// End gallery pop up

    //google fonts
    wp_enqueue_style( 'google-fonts', 'https://fonts.googleapis.com/css?family=Archivo+Narrow|Arimo|Berkshire+Swash|Bitter|Comfortaa|Dancing+Script|Dosis|Droid+Serif|Francois+One|Germania+One|Hammersmith+One|Indie+Flower|Lobster|Muli|Nosifer|PT+Sans|PT+Sans+Caption|PT+Sans+Narrow|Pacifico|Questrial|Roboto+Mono|Roboto+Slab|Source+Serif+Pro|Titillium+Web|Work+Sans|Rubik:700i' );
    // wp_add_inline_style( 'total-style', total_dymanic_styles() );

    wp_enqueue_script( 'peccular Premium-customscripts', get_template_directory_uri() . '/js/customscripts.js',array('jquery'),'',true);

    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
      wp_enqueue_script( 'comment-reply' );
  }

  $peccular_lite_color_scheme = get_theme_mod('peccular_template_color', '#fe5722');
  $peccular_lite_color_scheme2 = get_theme_mod('peccular_template_color2', '#44afdd');
  $header = get_theme_mod('header_textcolor', '#000');
  $peccular_lite_layout = get_theme_mod('peccular_lite_layout', 'cslayout');

  $custom_css = total_dymanic_styles();
  wp_add_inline_style( $handle, $custom_css );
}
add_action( 'wp_enqueue_scripts', 'peccular_lite_scripts' );
/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Implement the Custom style css.
 */
require get_template_directory() . '/inc/style.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/lz-customizer.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/lz-customizer-functions.php';
/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';
/**
 * Load Font Awesome list file.
 */
require get_template_directory() . '/inc/font-awesome-list.php';
/**
 * Load function file.
 */
require get_template_directory() . '/inc/functions.php';
/**
 * Add the Social buttons Widget.
 */
include_once( "functions/widget-social.php" );
require_once('functions/meta-data.php'); // ADD THE META DETA FOR THE PHP
/**
 * Copyrights
 */
if ( ! function_exists( 'peccular_lite_copyrights_credit' ) ) {
    function peccular_lite_copyrights_credit() { 
        global $mts_options
        ?>
        <!--start copyrights-->
        <div class="copyrights">
            <div class="container">
                <div id="copyright-note">
                    <span>Copyright <?php echo '&copy; '.date_i18n(__('Y','peccular')); ?> <?php bloginfo( 'name' ); ?>. All Rights Reserved

            <!--<div class="top">
            
                <a href="#top" class="toplink"><?php //_e('Back to Top','peccular Premium'); ?> &uarr;</a>
            </div>-->
        </div>
    </div>
</div>
<!--end copyrights-->
<?php }
}

/**
 * Custom Comments template
 */
if ( ! function_exists( 'peccular_lite_comments' ) ) {
    function peccular_lite_comment($comment, $args, $depth) { ?>
        <li <?php comment_class(); ?> id="li-comment-<?php comment_ID() ?>">
            <div id="comment-<?php comment_ID(); ?>" style="position:relative;" itemscope itemtype="http://schema.org/UserComments">
                <div class="comment-author vcard">
                    <?php echo get_avatar( $comment->comment_author_email, 70 ); ?>
                    <div class="comment-metadata">
                        <?php printf('<span class="fn" itemprop="creator" itemscope itemtype="http://schema.org/Person">%s</span>', get_comment_author_link()) ?>
                        <span class="comment-meta">
                          <?php edit_comment_link(__('(Edit)', 'peccular Premium'),'  ','') ?>
                      </span>
                  </div>
              </div>
              <?php if ($comment->comment_approved == '0') : ?>
               <em><?php _e('Your comment is awaiting moderation.', 'peccular Premium') ?></em>
               <br />
           <?php endif; ?>
           <div class="commentmetadata" itemprop="commentText">
               <?php comment_text() ?>
               <time><?php comment_date(get_option( 'date_format' )); ?></time>
               <span class="reply">
                <?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
            </span>
        </div>
    </div>
</li>
<?php }
}

/*
 * Excerpt
 */
function peccular_lite_excerpt($limit) {
  $excerpt = explode(' ', get_the_excerpt(), $limit);
  if (count($excerpt)>=$limit) {
    array_pop($excerpt);
    $excerpt = implode(" ",$excerpt);
} else {
    $excerpt = implode(" ",$excerpt);
}
$excerpt = preg_replace('`[[^]]*]`','',$excerpt);
return $excerpt;
}

/**
 * Shorthand function to check for more tag in post.
 *
 * @return bool|int
 */
function peccular_lite_post_has_moretag() {
    return strpos( get_the_content(), '<!--more-->' );
}

if ( ! function_exists( 'peccular_lite_readmore' ) ) {
    /**
     * Display a "read more" link.
     */
    function peccular_lite_readmore() {
        ?>
      <!--   <div class="readMore">
            <a href="<?php //echo esc_url( get_the_permalink() ); ?>" title="<?php //the_title_attribute(); ?>" target="_blank">
                <?php //_e( 'Continue Reading', 'peccular Premium' ); ?>
            </a>
        </div> -->

     
            <?php if( get_theme_mod('blogpage_button_display','show' ) == 'show') :
                      ?>
                      <?php
                        $bloginner_page_id = get_theme_mod('bloginner_page'); 
                        $bloginnerbutn_text = get_theme_mod('blogbutninner_text', 'Continue Reading');
                        ?>

                  
                         <a href="<?php echo esc_url( get_the_permalink() ); ?>" title="<?php the_title_attribute(); ?>" target="_blank">
                            <?php echo $bloginnerbutn_text; ?>
                                
                            </a>
                   
                      <?php endif ?>



        <?php 
    }
}

/**
 * Breadcrumbs
 */
if (!function_exists('peccular_lite_the_breadcrumb')) {
    function peccular_lite_the_breadcrumb() {
        if ( is_front_page() ) {
            return;
        }
        echo '<span typeof="v:Breadcrumb" class="root"><a rel="v:url" property="v:title" href="';
        echo esc_url( home_url() );
        /* =====breadcrumb text====== */
        $breadcrumbhometxtbutton = get_theme_mod('peccular_breadcrumbhometxt', 'Home'); 
        /* =====breadcrumb text====== */
        echo '">'.(sprintf( __( "$breadcrumbhometxtbutton", 'peccular Premium' )));
        echo '</a></span><span class="b-icon">></span>';
        if (is_single()) {
            $categories = get_the_category();
            if ( $categories ) {
                $level = 0;
                $hierarchy_arr = array();
                foreach ( $categories as $cat ) {
                    $anc = get_ancestors( $cat->term_id, 'category' );
                    $count_anc = count( $anc );
                    if (  0 < $count_anc && $level < $count_anc ) {
                        $level = $count_anc;
                        $hierarchy_arr = array_reverse( $anc );
                        array_push( $hierarchy_arr, $cat->term_id );
                    }
                }
                if ( empty( $hierarchy_arr ) ) {
                    $category = $categories[0];
                    echo '<span typeof="v:Breadcrumb"><a href="'. esc_url( get_category_link( $category->term_id ) ).'" rel="v:url" property="v:title">'.esc_html( $category->name ).'</a></span><span class="b-icon">></span>';
                } else {
                    foreach ( $hierarchy_arr as $cat_id ) {
                        $category = get_term_by( 'id', $cat_id, 'category' );
                        echo '<span typeof="v:Breadcrumb"><a href="'. esc_url( get_category_link( $category->term_id ) ).'" rel="v:url" property="v:title">'.esc_html( $category->name ).'</a></span><span class="b-icon">></span>';
                    }
                }
            }
            echo "<span><span class='treeEnd'>";
            the_title();
            echo "</span></span>";
        } elseif (is_page()) {
            $parent_id  = wp_get_post_parent_id( get_the_ID() );
            if ( $parent_id ) {
                $breadcrumbs = array();
                while ( $parent_id ) {
                    $page = get_page( $parent_id );
                    $breadcrumbs[] = '<span typeof="v:Breadcrumb"><a href="'.esc_url( get_permalink( $page->ID ) ).'" rel="v:url" property="v:title">'.esc_html( get_the_title($page->ID) ). '</a></span class="b-icon"><span>/</span>';
                    $parent_id  = $page->post_parent;
                }
                $breadcrumbs = array_reverse( $breadcrumbs );
                foreach ( $breadcrumbs as $crumb ) { echo $crumb; }
            }
            echo "<span><span class='treeEnd'>";
            the_title();
            echo "</span></span>";
        } elseif (is_category()) {
            global $wp_query;
            $cat_obj = $wp_query->get_queried_object();
            $this_cat_id = $cat_obj->term_id;
            $hierarchy_arr = get_ancestors( $this_cat_id, 'category' );
            if ( $hierarchy_arr ) {
                $hierarchy_arr = array_reverse( $hierarchy_arr );
                foreach ( $hierarchy_arr as $cat_id ) {
                    $category = get_term_by( 'id', $cat_id, 'category' );
                    echo '<span typeof="v:Breadcrumb"><a href="'.esc_url( get_category_link( $category->term_id ) ).'" rel="v:url" property="v:title">'.esc_html( $category->name ).'</a></span><span class="b-icon">/</span>';
                }
            }
            echo "<span><span class='treeEnd'>";
            single_cat_title();
            echo "</span></span>";
        } elseif (is_author()) {
            echo "<span><span class='treeEnd'>";
            if(get_query_var('author_name')) :
                $curauth = get_user_by('slug', get_query_var('author_name'));
            else :
                $curauth = get_userdata(get_query_var('author'));
            endif;
            echo esc_html( $curauth->nickname );
            echo "</span></span>";
        } elseif (is_search()) {
            echo "<span><span class='treeEnd'>";
            the_search_query();
            echo "</span></span>";
        } elseif (is_tag()) {
            echo "<span><span class='treeEnd'>";
            single_tag_title();
            echo "</span></span>";
        }
    }
}


/*
 * Google Fonts
 */
function peccular_lite_fonts_url() {
    $fonts_url = '';

    /* Translators: If there are characters in your language that are not
    * supported by Monda, translate this to 'off'. Do not translate
    * into your own language.
    */
    $monda = _x( 'on', 'Monda font: on or off', 'peccular Premium' );

    if ( 'off' !== $monda ) {
        $font_families = array();

        if ( 'off' !== $monda ) {
            $font_families[] = urldecode('Roboto:400,500,700,900');
        }

        $query_args = array(
            'family' => urlencode( implode( '|', $font_families ) ),
            //'subset' => urlencode( 'latin,latin-ext' ),
        );

        $fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );
    }

    return $fonts_url;
}

function peccular_lite_scripts_styles() {
    wp_enqueue_style( 'theme-slug-fonts', peccular_lite_fonts_url(), array(), null );

}
add_action( 'wp_enqueue_scripts', 'peccular_lite_scripts_styles' );

/**
 * WP Mega Menu Plugin Support
 */
function peccular_lite_megamenu_parent_element( $selector ) {
    return '.primary-navigation .container';
}
add_filter( 'wpmm_container_selector', 'peccular_lite_megamenu_parent_element' );

/**
 * Determines whether the WooCommerce plugin is active or not.
 * @return bool
 */
function peccular_lite_is_wc_active() {
    if ( is_multisite() ) {
        include_once( ABSPATH . 'wp-admin/includes/plugin.php' );

        return is_plugin_active( 'woocommerce/woocommerce.php' );
    } else {
        return in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) );
    }
}

/**
 * WooCommerce
 */
if ( peccular_lite_is_wc_active() ) {
    if ( !function_exists( 'mts_loop_columns' )) {
        /**
         * Change number or products per row to 3
         *
         * @return int
         */
        function mts_loop_columns() {
            return 3; // 3 products per row
        }
    }
    add_filter( 'loop_shop_columns', 'mts_loop_columns' );

    /**
     * Redefine woocommerce_output_related_products()
     */
    function woocommerce_output_related_products() {
        $args = array(
            'posts_per_page' => 3,
            'columns' => 3,
        );
        woocommerce_related_products($args); // Display 3 products in rows of 1
    }
    
    global $pagenow;
    if ( is_admin() && isset( $_GET['activated'] ) && $pagenow == 'themes.php' ) {
        /**
         * Define WooCommerce image sizes.
         */
        function peccular_lite_woocommerce_image_dimensions() {
            $catalog = array(
                'width'     => '210',   // px
                'height'    => '155',   // px
                'crop'      => 1        // true
            );
            $single = array(
                'width'     => '326',   // px
                'height'    => '444',   // px
                'crop'      => 1        // true
            );
            $thumbnail = array(
                'width'     => '74',    // px
                'height'    => '74',   // px
                'crop'      => 0        // false
            );
            // Image sizes
            update_option( 'shop_catalog_image_size', $catalog );       // Product category thumbs
            update_option( 'shop_single_image_size', $single );         // Single product image
            update_option( 'shop_thumbnail_image_size', $thumbnail );   // Image gallery thumbs
        }
        add_action( 'init', 'peccular_lite_woocommerce_image_dimensions', 1 );
    }


    /**
     * Change the number of product thumbnails to show per row to 4.
     *
     * @return int
     */
    function peccular_lite_woocommerce_thumb_cols() {
     return 4; // .last class applied to every 4th thumbnail
 }
 add_filter( 'woocommerce_product_thumbnails_columns', 'peccular_lite_woocommerce_thumb_cols' );


    /**
     * Ensure cart contents update when products are added to the cart via AJAX.
     *
     * @param $fragments
     *
     * @return mixed
     */
    function peccular_lite_header_add_to_cart_fragment( $fragments ) {
        global $woocommerce;
        ob_start(); ?>
        
        <a class="cart-contents" href="<?php echo esc_url( $woocommerce->cart->get_cart_url() ); ?>" title="<?php _e( 'View your shopping cart', 'peccular Premium' ); ?>"><?php echo sprintf( _n( '%d item', '%d items', $woocommerce->cart->cart_contents_count, 'peccular Premium' ), $woocommerce->cart->cart_contents_count );?> - <?php echo $woocommerce->cart->get_cart_total(); ?></a>
        
        <?php $fragments['a.cart-contents'] = ob_get_clean();
        return $fragments;
    }
    add_filter( 'add_to_cart_fragments', 'peccular_lite_header_add_to_cart_fragment' );

    /**
     * Optimize WooCommerce Scripts
     * Updated for WooCommerce 2.0+
     * Remove WooCommerce Generator tag, styles, and scripts from non WooCommerce pages.
     */
    function peccular_lite_manage_woocommerce_styles() {
        //remove generator meta tag
        remove_action( 'wp_head', array( $GLOBALS['woocommerce'], 'generator' ) );

        //first check that woo exists to prevent fatal errors
        if ( function_exists( 'is_woocommerce' ) ) {
            //dequeue scripts and styles
            if ( ! is_woocommerce() && ! is_cart() && ! is_checkout() ) {
                wp_dequeue_style( 'woocommerce-layout' );
                wp_dequeue_style( 'woocommerce-smallscreen' );
                wp_dequeue_style( 'woocommerce-general' );
                wp_dequeue_style( 'wc-bto-styles' ); //Composites Styles
                wp_dequeue_script( 'wc-add-to-cart' );
                wp_dequeue_script( 'wc-cart-fragments' );
                wp_dequeue_script( 'woocommerce' );
                wp_dequeue_script( 'jquery-blockui' );
                wp_dequeue_script( 'jquery-placeholder' );



            }
        }
    }
    add_action( 'wp_enqueue_scripts', 'peccular_lite_manage_woocommerce_styles', 99 );

    // Remove WooCommerce generator tag.
    remove_action('wp_head', 'wc_generator_tag');
}

/**
 * Post Layout for Archives
 */
if ( ! function_exists( 'peccular_lite_archive_post' ) ) {
    /**
     * Display a post of specific layout.
     * 
     * @param string $layout
     */
    function peccular_lite_archive_post( $layout = '' ) { 
        $peccular_lite_full_posts = get_theme_mod('peccular_lite_full_posts', '0'); ?>
        <article class="post excerpt col-md-6 col-sm-6 col-xs-12 wow zoomIn">
                <?php
            if ( is_sticky() && is_home() && ! is_paged() ) {
                printf( '<span class="sticky-post">%s</span>', __( 'Featured', 'peccular Premium' ) );
            } ?>
            <?php if ( is_single() ) : ?>
                <div class="post-date-publishable"><?php the_time( get_option( 'date_format' ) ); ?></div>
            <?php endif; ?>



<!-- category page -->
 <div class="inner-blog-post wow zoomIn">
    <div class="inner-blogpost">
        <?php if ( empty($peccular_lite_full_posts) ) : ?>
                <?php if ( has_post_thumbnail() ) { ?>
         <div class="ht-blog-thumbnail">

            <a href="<?php the_permalink(); ?>">
                 
                <?php the_post_thumbnail('peccular Premium-featured',array('title' => '')); ?>
                <?php if (function_exists('wp_review_show_total')) wp_review_show_total(true, 'latestPost-review-wrapper'); ?>

                <div class="overlay"></div>
                             <svg xmlns="http://www.w3.org/2000/svg" width="394" height="257.998" viewBox="0 0 394 257.998">
  <g id="NoPath_-_Copy_35_" data-name="NoPath - Copy (35)" transform="translate(0 -0.459)" fill="#f1f5f5">
    <path d="M 376 257.95751953125 L 18 257.95751953125 C 15.65170001983643 257.95751953125 13.3725004196167 257.3868408203125 11.22574996948242 256.2612915039062 C 9.14330005645752 255.16943359375 7.271100044250488 253.6039733886719 5.661200046539307 251.6084289550781 C 4.044950008392334 249.6049346923828 2.775399923324585 247.2700347900391 1.887750029563904 244.6685791015625 C 0.9668999910354614 241.9698791503906 0.5 239.1021270751953 0.5 236.1450347900391 L 0.5 14.43943214416504 C 2.000698566436768 13.78446960449219 9.171669960021973 10.75584888458252 20.04509925842285 7.762277126312256 C 27.21985054016113 5.787027359008789 34.57915115356445 4.213227272033691 41.91854858398438 3.084627389907837 C 51.08985137939453 1.67437732219696 60.25569915771484 0.9593272805213928 69.1614990234375 0.9593272805213928 C 80.43695068359375 0.9593272805213928 91.46185302734375 2.107627391815186 101.9299011230469 4.372377395629883 C 111.5107498168945 6.445127487182617 122.1716537475586 9.72647762298584 134.5218963623047 14.40382766723633 C 145.5748443603516 18.58987808227539 157.0391540527344 23.52512741088867 168.1260070800781 28.29792785644531 C 200.9235534667969 42.41692733764648 234.8377532958984 57.01662826538086 268.5657043457031 57.5894775390625 C 269.4581604003906 57.6046257019043 270.3641357421875 57.61227798461914 271.2586059570312 57.61227798461914 C 306.2289428710938 57.61172866821289 337.820556640625 45.89332580566406 358.1647033691406 36.0628776550293 C 369.6794128417969 30.49887657165527 378.8890380859375 24.9376277923584 384.58740234375 21.25207710266113 C 389.0589904785156 18.35997009277344 392.1306457519531 16.13628387451172 393.5 15.11789035797119 L 393.5 236.1450347900391 C 393.5 239.1021270751953 393.0331115722656 241.9698791503906 392.1122436523438 244.6685791015625 C 391.224609375 247.2700347900391 389.9550476074219 249.6049346923828 388.3388061523438 251.6084289550781 C 386.7289123535156 253.6039733886719 384.856689453125 255.16943359375 382.7742614746094 256.2612915039062 C 380.6275024414062 257.3868408203125 378.3482971191406 257.95751953125 376 257.95751953125 Z" stroke="none"/>
    <path d="M 376 257.45751953125 C 385.3738403320312 257.45751953125 393 247.8967742919922 393 236.1450347900391 L 393 16.10666084289551 C 391.3899841308594 17.28066444396973 388.6158752441406 19.24203109741211 384.8589477539062 21.67192649841309 C 379.1487426757812 25.36512756347656 369.9200439453125 30.93792724609375 358.3822631835938 36.51307678222656 C 337.9910888671875 46.36622619628906 306.3236083984375 58.11172866821289 271.2586059570312 58.11227798461914 C 270.3603515625 58.11227798461914 269.4514465332031 58.10457611083984 268.5571899414062 58.08937835693359 C 234.7306518554688 57.51487731933594 200.7704010009766 42.89532852172852 167.9282531738281 28.75717735290527 C 156.8464508056641 23.9865779876709 145.3873443603516 19.05352783203125 134.3448028564453 14.87142753601074 C 122.0180511474609 10.20297718048096 111.3804473876953 6.928527355194092 101.8242034912109 4.861077308654785 C 91.39084625244141 2.603827238082886 80.40155029296875 1.459327340126038 69.1614990234375 1.459327340126038 C 60.28609848022461 1.459327340126038 51.15105056762695 2.171627283096313 42.01005172729492 3.576477289199829 C 34.69255065917969 4.701027393341064 27.35490036010742 6.269427299499512 20.20095062255859 8.237977027893066 C 9.944231033325195 11.06033515930176 2.990514993667603 13.91421318054199 1 14.76793003082275 L 1 236.1450347900391 C 1 247.8967742919922 8.626150131225586 257.45751953125 18 257.45751953125 L 376 257.45751953125 M 376 258.45751953125 L 18 258.45751953125 C 8.058850288391113 258.45751953125 0 248.4678802490234 0 236.1450347900391 L 0 14.11387729644775 C 0 14.11387729644775 29.98397064208984 0.4593315720558167 69.1614990234375 0.4593315720558167 C 79.59632873535156 0.4593315720558167 90.690673828125 1.429233074188232 102.0356521606445 3.883677244186401 C 154.4052429199219 15.21367740631104 211.7184448242188 56.12387847900391 268.5741882324219 57.08952713012695 C 269.471923828125 57.10477447509766 270.3650817871094 57.11228942871094 271.2585754394531 57.11227798461914 C 338.7728881835938 57.11120986938477 394 14.11387729644775 394 14.11387729644775 L 394 236.1450347900391 C 394 248.4678802490234 385.941162109375 258.45751953125 376 258.45751953125 Z" stroke="none" fill="#f1f5f5"/>
  </g>
</svg>
  
        </div>

   <?php } else { ?>
    <?php } ?>

    <div class="peccular-blog-single">    
                 <div class="peccular-blog-comment">
                         <div class="row">
                         <?php if (get_theme_mod('peccular_show_date',true) != false){ ?>   
                        <div class="col-md-6 col-sm-6 textleft width-5">
                        <i class="fa fa-calendar-o" aria-hidden="true"></i><span><?php echo get_the_date( 'j M Y' ); ?></span></div>
                        <?php }?>
                          <?php if (get_theme_mod('peccular_show_comment',true) != false){ ?>   
                            <div class="col-md-6 col-sm-6 width-7">
                         <i class="fa fa-folder-open" aria-hidden="true"></i><span><?php echo $my_var = get_comments_number(); ?> Comment</span>
                        </div>
                         <?php }?>
                        <div class="clearfix"></div>
                                </div>
                    </div>  


            <a href="<?php the_permalink(); ?>"><h2><?php the_title(); ?></h2></a>
             <div class="clearfix"></div>
                <div class="clearfix"></div>

                      <?php if (get_theme_mod('blog_page_excerpt_display',true) != false){ ?>
                           <div class="inner-blog-excerpt">
                               <?php echo peccular_lite_excerpt(30); ?>
                          </div>
                      <?php } ?>   
                       <div class="clearfix"></div>
                       
               <?php
                     $peccular_blog_button_text = get_theme_mod('peccular_blog_button_text', 'Read more'); 
                 ?>
                <?php if( get_theme_mod('peccular_sblog_button_enable',true) == true){ ?>
                    <div class="b-readmore">
                       <a href="<?php the_permalink(); ?>" class="read-btn"><?php echo ($peccular_blog_button_text );  ?>...</a>
                     </div>
                 <?php }?>
      
                

      <?php else : ?>
        <?php if (peccular_lite_post_has_moretag()) : ?>
    
       <div class="clearfix"></div>
        </div>
          </a>
       <div class="clearfix"></div> 
                   
</div>
            
</div> 

<!-- END category page -->

 
                    <?php endif; ?>
                <?php endif; ?>
            <div class="clearfix"></div>
            </article>
       
        <?php }
    }


/**
 * Extras
 */
add_action( 'customize_controls_print_styles', 'peccular_customizer_stylesheet' );

function peccular_load_custom_wp_admin_style( $hook ) {
    if ( 'appearance_page_about-peccular_mag' !== $hook ) {
        return;
    }
    wp_enqueue_style( 'peccular_mag-custom-admin-css', get_template_directory_uri() . '/css/themeinfo.css', false, '1.0.0' );
}
add_action( 'admin_enqueue_scripts', 'peccular_load_custom_wp_admin_style' );


// Adding Custome Post Type
function createCustomeTypes() {
           // Courses Custome type
    register_post_type( 'our-courses',
        array( 
            'labels' => array(
                'name' => __( 'Courses' , 'peccular Premium'),
                'singular_name' => __( 'Courses', 'peccular Premium' )
            ),
            'public' => true,
            'featured_image'=>true,
            'has_archive' => true,
            'menu_icon' => 'dashicons-format-aside', //  The url to the icon to be used for this menu or the name of the icon from the iconfont
            'supports' => array('title', 'editor', 'thumbnail', 'page-attributes'),
        )
    ); 

        // SLIDER Custome type
    register_post_type( 'slider',
        array(
            'labels' => array(
                'name' => __( 'Sliders' , 'paccular'),
                'singular_name' => __( 'Slider', 'paccular' )
            ),
            'public' => true,
            'featured_image'=>true,
            'has_archive' => true,
            'menu_icon' => 'dashicons-images-alt', //  The url to the icon to be used for this menu or the name of the icon from the iconfont
            'supports' => array('title', 'thumbnail', 'editor' , 'page-attributes'),
        )
    );
}
add_action( 'init', 'createCustomeTypes' );



// for slider button url
function slider2BtnUrlCutomFieldHtml2(){
    global $post;
    // get the saved value 

    $sliderbtn1url = get_post_meta($post->ID, 'sliderbtn1url', false);
    $sliderbtn1url = !empty($sliderbtn1url[0])?$sliderbtn1url[0]:'';

    // Use nonce for verification
    wp_nonce_field(plugin_basename(__FILE__), 'slider2Btn_links');
    echo '<table id="slider2Btn" width="100%">';

    echo '<table id="slider2Btn" width="100%">';
    echo '<tr> 
    <th width="10%"><span class="dashicons dashicons-info"></span></th>
    <td width="90%"><input type="text" name="sliderbtn1url" width="100%" placeholder="Slider Button Url Here" value="'.$sliderbtn1url.'" /></td>
    </tr>';
    echo '</table>';
}

function addSlider2btnHook(){
     // add_meta_box('slider1_btn_url', __('Add Slider Button Url Here', 'peccular-premium'), 'slider2BtnUrlCutomFieldHtml2', 'slider', 'normal', 'high');
    add_meta_box('slider2_btn_url', __('Add Slider Button Url Here', 'peccular-premium'), 'slider2BtnUrlCutomFieldHtml2', 'slider', 'normal', 'high');
}
function saveslider2btnUrlCutomData($post_id){
    // If it is our form has not been submitted, so we dont want to do anything
    if(defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
        return;

    $sliderbtn1url = !empty($_POST['sliderbtn1url'])?$_POST['sliderbtn1url']:'';
    update_post_meta($post_id, 'sliderbtn1url', $sliderbtn1url);
}
add_action('add_meta_boxes', 'addSlider2btnHook');
add_action('save_post', 'saveslider2btnUrlCutomData');


// for slider button text

function slider1btntextCutomFieldHtml2(){
    global $post;
    // get the saved value 
    $slider1btntext = get_post_meta($post->ID, 'slider1btntext', false);
    $slider1btntext = !empty($slider1btntext[0])?$slider1btntext[0]:'';
    
    // Use nonce for verification
    wp_nonce_field(plugin_basename(__FILE__), 'sliderbtn_text');
    echo '<table id="sliderbtntext" width="100%">';

      echo '<table id="sliderbtntext" width="100%">';
    echo '<tr> 
    <th width="10%"><span class="dashicons dashicons-edit-large"></span></th>
    <td width="90%"><input type="text" name="slider1btntext" width="100%" placeholder="Slider Button Text" value="'.$slider1btntext.'" /></td>
    </tr>';
    echo '</table>';
}

function addslider1btntextHook(){

    add_meta_box('test_slider1btntext', __('Add Slider Button Text', 'peccular-premium'), 'slider1btntextCutomFieldHtml2', 'slider', 'normal', 'high');
}

function saveslider1btntextCutomData($post_id){
    // If it is our form has not been submitted, so we dont want to do anything
    if(defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
        return;

     if (isset($_POST['slider1btntext'])) {

    $slider1btntext = $_POST['slider1btntext'];
    update_post_meta($post_id, 'slider1btntext', $slider1btntext);
    
    }
}
add_action('add_meta_boxes', 'addslider1btntextHook');
add_action('save_post', 'saveslider1btntextCutomData');





function testimonialsDesignationCutomFieldHtml(){
    global $post;
    // get the saved value 
    $designation = get_post_meta($post->ID, 'designation', false);
    $designation = !empty($designation[0])?$designation[0]:'';

    // Use nonce for verification
    wp_nonce_field(plugin_basename(__FILE__), 'testimonials_social_media_links');
    echo '<table id="socialUrls" width="100%">';
    echo '<tr> 
    <th width="10%"><span class="dashicons dashicons-welcome-learn-more
"></span></th>
    <td width="90%"><input type="text" name="designation" width="100%" placeholder="Designation" value="'.$designation.'" /></td>
    </tr>';
    echo '</table>';
}
function addtestimonialsHook(){
    add_meta_box('peccular-testimonials-designation', __('Add Designation', 'peccular'), 'testimonialsDesignationCutomFieldHtml', 'our-testimonial', 'normal', 'high');
}
/**
 * Method to save the custom field for the testimonial posts 
 * When the post is saved, saves our custom data 
 * @param integer $post_id - An id of the post 
 * @author peccular <support@peccular.com>
 * @since V 1.1  09th jan 2022
 **/
function savetestimonialsSocialCutomData($post_id){
    // If it is our form has not been submitted, so we dont want to do anything
    if(defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
        return;
    if(empty($_POST['designation']) ){
        // echo 'empty --> '; exit;       
        return;
    }

    $designation = $_POST['designation'];
    update_post_meta($post_id, 'designation', $designation);
}
add_action('add_meta_boxes', 'addtestimonialsHook');
add_action('save_post', 'savetestimonialsSocialCutomData');
/***** End Add custome fields for testimonials section *****/




function coursesDesignationCutomFieldHtml(){
    global $post;
    // get the saved value 
    $coursesseats = get_post_meta($post->ID, 'coursesseats', false);
    $coursesseats = !empty($coursesseats[0])?$coursesseats[0]:'';

    $coursesmonth = get_post_meta($post->ID, 'coursesmonth', false);
    $coursesmonth = !empty($coursesmonth[0])?$coursesmonth[0]:'';

    // Use nonce for verification
    wp_nonce_field(plugin_basename(__FILE__), 'testimonials_social_media_links');
    echo '<table id="socialUrls" width="100%">';
    echo '<tr> 
    <th width="10%"><span class="dashicons dashicons-category
"></span></th>
    <td width="90%"><input type="text" name="coursesseats" width="100%" placeholder="Seats" value="'.$coursesseats.'" /></td>
    </tr>';

    echo '<tr> 
    <th width="10%"><span class="dashicons dashicons-category
"></span></th>
    <td width="90%"><input type="text" name="coursesmonth" width="100%" placeholder="Month" value="'.$coursesmonth.'" /></td>
    </tr>';

    echo '</table>';
}
function addcoursesHook(){
    add_meta_box('courses_area_seats', __('Courses Details ', 'peccular'), 'coursesDesignationCutomFieldHtml', 'our-courses', 'normal', 'high');
}

/**
 * Method to save the custom field for the testimonial posts 
 * When the post is saved, saves our custom data 
 * @param integer $post_id - An id of the post 
 * @author peccular <support@peccular.com>
 * @since V 1.1  09th jan 2022
 **/
function savecoursesSocialCutomData($post_id){
    // If it is our form has not been submitted, so we dont want to do anything
    if(defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
        return;
    if(empty($_POST['coursesseats']) || empty($_POST['coursesmonth']) ){
        // echo 'empty --> '; exit;       
        return;
    }

    $coursesseats = $_POST['coursesseats'];
    update_post_meta($post_id, 'coursesseats', $coursesseats);

    $coursesmonth = $_POST['coursesmonth'];
    update_post_meta($post_id, 'coursesmonth', $coursesmonth);
}
add_action('add_meta_boxes', 'addcoursesHook');
add_action('save_post', 'savecoursesSocialCutomData');
/***** End Add custome fields for testimonials section *****/






/***** Start Add custome fields for team section *****/
/**
 * Method to save the custom field for the team posts 
 * When the post is saved, saves our custom data 
 * @author peccular <support@peccular.com>
 * @since V 1.1  09th jan 2022
 **/
function teamSocialURLsCutomFieldHtml(){
    global $post;

    $teamTwitter = get_post_meta($post->ID, 'teamTwitter', false);
    $teamTwitterValue = !empty($teamTwitter[0])?$teamTwitter[0]:''; 
    $teamFacebook = get_post_meta($post->ID, 'teamFacebook', false);
    $teamFacebookValue = !empty($teamFacebook[0])?$teamFacebook[0]:'';    
    $teamInstagram = get_post_meta($post->ID, 'teamInstagram', false);
    $teamInstagramValue = !empty($teamInstagram[0])?$teamInstagram[0]:'';
    // $teamTelegram = get_post_meta($post->ID, 'teamTelegram', false);
    // $teamTelegramValue = !empty($teamTelegram[0])?$teamTelegram[0]:'';
    

    // Use nonce for verification

    wp_nonce_field(plugin_basename(__FILE__), 'Team_social_media_links');
    echo '<table id="socialUrls" width="100%">';

     echo '<tr> 
    <th><span class="dashicons dashicons-twitter"></span></th>
    <td><input type="text" name="teamTwitter" placeholder="Twitter URL" width="100%" value="'.$teamTwitterValue.'" /></td>
    </tr>';

    echo '<tr> 
    <th width="10%"><span class="dashicons dashicons-facebook"></span></th>
    <td width="90%"><input type="text" name="teamFacebook" width="100%" placeholder="Facebook URL" value="'.$teamFacebookValue.'" /></td>
    </tr>';   
   
    echo '<tr> 
    <th><span class="dashicons dashicons-smartphone"></span></th>
    <td><input type="text" name="teamInstagram" placeholder="Instagram URL" width="100%" value="'.$teamInstagramValue.'" /></td>
    </tr>';
    
    // echo '<tr> 
    // <th><span class="dashicons dashicons-email-alt2"></span></th>
    // <td><input type="text" name="teamTelegram" placeholder="Telegram URL" width="100%" value="'.$teamTelegramValue.'" /></td>
    // </tr>';

    echo '</table>';

   
}

/**
 * Method to save the custom field for the slider posts 
 * When the post is saved, saves our custom data 
 * @author peccular <support@peccular.com>
 * @since V 1.1  09th jan 2022
 **/
function teamDesignationCutomFieldHtml(){
    global $post;
    // get the saved value 
    $designation = get_post_meta($post->ID, 'designation', false);
    $designation = !empty($designation[0])?$designation[0]:'';

    // Use nonce for verification
    wp_nonce_field(plugin_basename(__FILE__), 'Team_social_media_links');
    echo '<table id="socialUrls" width="100%">';
    echo '<tr> 
    <th width="10%"><span class="dashicons dashicons-welcome-learn-more"></span></th>
    <td width="90%"><input type="text" name="designation" width="100%" placeholder="Designation" value="'.$designation.'" /></td>
    </tr>';
    echo '</table>';
}


function addTeamHook(){
     add_meta_box('peccular-team-social-icon', __('Add Social media links', 'peccular'), 'teamSocialURLsCutomFieldHtml', 'our-team', 'normal', 'high');
    add_meta_box('peccular-team-designation', __('Add Designation', 'peccular'), 'teamDesignationCutomFieldHtml', 'our-team', 'normal', 'high');
}

/**
 * Method to save the custom field for the testimonial posts 
 * When the post is saved, saves our custom data 
 * @param integer $post_id - An id of the post 
 * @author peccular <support@peccular.com>
 * @since V 1.1  09th jan 2022
 **/
function saveTeamSocialCutomData($post_id){
    // If it is our form has not been submitted, so we dont want to do anything
    if(defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
        return;
    if(empty($_POST['teamFacebook']) && empty($_POST['teamTwitter']) && empty($_POST['teamInstagram']) && empty($_POST['designation']) ){
        // echo 'empty --> '; exit;       
        return;

       
    }
   
    $teamFacebook = $_POST['teamFacebook'];
    update_post_meta($post_id, 'teamFacebook', $teamFacebook);
    $teamTwitter = $_POST['teamTwitter'];
    update_post_meta($post_id, 'teamTwitter', $teamTwitter);   
    $teamInstagram = $_POST['teamInstagram'];
    update_post_meta($post_id, 'teamInstagram', $teamInstagram);
    // $teamTelegram = $_POST['teamTelegram'];
    // update_post_meta($post_id, 'teamTelegram', $teamTelegram);

    $designation = $_POST['designation'];
    update_post_meta($post_id, 'designation', $designation);
}
add_action('add_meta_boxes', 'addTeamHook');
add_action('save_post', 'saveTeamSocialCutomData');



/***** End Add custome fields for team section *****/


/**
 * Method to save the custom field for the testimonial posts 
 * When the post is saved, saves our custom data 
 * @param integer $post_id - An id of the post 
 * @author peccular <support@peccular.com>
 * @since V 1.1  09th jan 2022
 **/
function getFonts($list = false, $index = -1){
    $fonts = array(
        "'Archivo Narrow', sans-serif",
        "'Archivo Black', sans-serif",
        "'Arial', sans-serif",
        "'Arimo', sans-serif",
        "'Allerta', sans-serif",
        "'Alex Brush', cursive",
        "'Berkshire Swash', cursive",
        "'Bitter', serif",
        "'Carter One', cursive",
        "'Comfortaa', cursive",
        "'Dancing Script', cursive",
        "'Dosis', sans-serif",
        "'Droid Serif', serif",
        "'Francois One', sans-serif",
        "'Germania One', cursive",
        "'Hammersmith One', sans-serif",
        "'Indie Flower', cursive",
        "'Lobster', cursive",
        "'Lato', sans-serif",
        "'Muli', sans-serif",
        "'Nosifer', cursive",
        "'Oswald', sans-serif",
        "'PT Sans Caption', sans-serif",
        "'PT Sans Narrow', sans-serif",
        "'PT Sans', sans-serif",
        "'Pacifico', cursive",
        "'Praise', cursive",
        "'Poppins', sans-serif",
        "'Open Sans', sans-serif",
        "'Montserrat', sans-serif",
        "'Pontano Sans', sans-serif",
        "'Questrial', sans-serif",
        "'Roboto Mono', monospace",
        "'Roboto Slab', serif",
        "'Roboto', sans-serif",
        "'Rubik', sans-serif",
        "'Source Serif Pro', serif",
        "'Titillium Web', sans-serif",
        "'Biryani', sans-serif", 
        "'Montserrat Alternates', sans-serif",
        "'Work Sans', sans-serif",
        "'Arvo', serif",
        "'Passion One', cursive",
        "'Schoolbell', cursive",
        "'DM Serif Display', serif",
        "'Varela Round', sans-serif"
    );
    if($list == true){
        foreach ($fonts as $key => $value) {
            $fonts[$key] = str_replace("'", "", $value);
        }
        asort($fonts);
        return $fonts;
    }
    $len = count($fonts);
    if(is_integer($index) && $index >= 0 && $index < $len){
        return $fonts[$index];
    }else{
        return $fonts;
    }
}

// dropdown animation
function getAnimations($list = false, $index = -1){
    $animations = array(
        "zoomIn .3s ease-in-out",
        "bounceInUp .5s ease-in-out",
        "fadeInUp .3s ease-in-out",
    );
    if($list == true){
        foreach ($animations as $key => $value) {
            $animations[$key] = str_replace("'", "", $value);
        }
        asort($animations);
        return $animations;
    }
    $len = count($animations);
    if(is_integer($index) && $index >= 0 && $index < $len){
        return $animations[$index];
    }else{
        return $animations;
    }
}

// menu font case
function getfontcase($list = false, $index = -1){
    $fontcase = array(
        "none",
        "capitalize",
        "lowercase",
        "uppercase",
    );
    if($list == true){
        foreach ($fontcase as $key => $value) {
            $fontcase[$key] = str_replace("'", "", $value);
        }
        asort($fontcase);
        return $fontcase;
    }
    $len = count($fontcase);
    if(is_integer($index) && $index >= 0 && $index < $len){
        return $fontcase[$index];
    }else{
        return $fontcase;
    }
}

//Blog layout
function getBlogLayout($list = false, $index = -1){
    $bloglayout = array(
        'No Sidebar',
        'Left Sidebar',
        'Right Sidebar'
    );
    if($list == true){
        foreach ($bloglayout as $key => $value) {
            $bloglayout[$key] = str_replace("'", "", $value);
        }
        asort($bloglayout);
        return $bloglayout;
    }
    $len = count($bloglayout);
    if(is_integer($index) && $index >= 0 && $index < $len){
        return $bloglayout[$index];
    }else{
        return $bloglayout;
    }
}


//Single post Blog layout
function getBlogSPostLayout($list = false, $index = -1){
    $blogspostlayout = array(
        'Right Sidebar',
        'Left Sidebar',
        'No Sidebar'
    );
    if($list == true){
        foreach ($blogspostlayout as $key => $value) {
            $blogspostlayout[$key] = str_replace("'", "", $value);
        }
        asort($blogspostlayout);
        return $blogspostlayout;
    }
    $len = count($blogspostlayout);
    if(is_integer($index) && $index >= 0 && $index < $len){
        return $blogspostlayout[$index];
    }else{
        return $blogspostlayout;
    }
}

// //Testimonial Inner page layout
// function getTestimonialInnerLayout($list = false, $index = -1){
//     $testimoniallayout = array(
//         'No Sidebar',
//         'Left Sidebar',
//         'Right Sidebar'
//     );
//     if($list == true){
//         foreach ($testimoniallayout as $key => $value) {
//             $testimoniallayout[$key] = str_replace("'", "", $value);
//         }
//         asort($testimoniallayout);
//         return $testimoniallayout;
//     }
//     $len = count($testimoniallayout);
//     if(is_integer($index) && $index >= 0 && $index < $len){
//         return $testimoniallayout[$index];
//     }else{
//         return $testimoniallayout;
//     }
// }

//Page layout
function getPageLayout($list = false, $index = -1){
    $pagelayout = array(
        'No Sidebar',
        'Left Sidebar',
        'Right Sidebar'
    );
    if($list == true){
        foreach ($pagelayout as $key => $value) {
            $pagelayout[$key] = str_replace("'", "", $value);
        }
        asort($pagelayout);
        return $pagelayout;
    }
    $len = count($pagelayout);
    if(is_integer($index) && $index >= 0 && $index < $len){
        return $pagelayout[$index];
    }else{
        return $pagelayout;
    }
}


//Shop page layout
function getShopPageLayout($list = false, $index = -1){
    $shoppagelayout = array(
        'No Sidebar',
        'Right Sidebar',       
        'Left Sidebar'
        
    );
    if($list == true){
        foreach ($shoppagelayout as $key => $value) {
            $shoppagelayout[$key] = str_replace("'", "", $value);
        }
        asort($shoppagelayout);
        return $shoppagelayout;
    }
    $len = count($shoppagelayout);
    if(is_integer($index) && $index >= 0 && $index < $len){
        return $shoppagelayout[$index];
    }else{
        return $shoppagelayout;
    }
}

/**
 * show the pagination for the custome or normal post types
 * @param object $customeQuery - An onject of a query post
 * @author peccular <support@peccular.com>
 * @since V 1.1  09th jan 2022
 **/
function lzGetPagination($customQuery){
    if(!is_object($customQuery)){return false;}
    $total_pages = $customQuery->max_num_pages;
    $big = 999999999;
    $current_page = max(1, get_query_var('paged'));
    echo paginate_links(array(
        'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
        'format' => '?paged=%#%',
        'current' => $current_page,
        'total' => $total_pages,    
    ));
}


if ( class_exists( 'WP_Customize_Panel' ) ) {

  class peccular_WP_Customize_Panel extends WP_Customize_Panel {

    public $panel;

    public $type = 'peccular_panel';

    public function json() {

      $array = wp_array_slice_assoc( (array) $this, array( 'id', 'description', 'priority', 'type', 'panel', ) );
      $array['title'] = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
      $array['content'] = $this->get_content();
      $array['active'] = $this->active();
      $array['instanceNumber'] = $this->instance_number;

      return $array;

    }

  }

}

if ( class_exists( 'WP_Customize_Section' ) ) {

  class peccular_WP_Customize_Section extends WP_Customize_Section {

    public $section;

    public $type = 'peccular_section';

    public function json() {

      $array = wp_array_slice_assoc( (array) $this, array( 'id', 'description', 'priority', 'panel', 'type', 'description_hidden', 'section', ) );
      $array['title'] = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
      $array['content'] = $this->get_content();
      $array['active'] = $this->active();
      $array['instanceNumber'] = $this->instance_number;

      if ( $this->panel ) {

        $array['customizeAction'] = sprintf( 'Customizing &#9656; %s', esc_html( $this->manager->get_panel( $this->panel )->title ) );

      } else {

        $array['customizeAction'] = 'Customizing';

      }

      return $array;

    }

  }

}
// for overlay opacity
function peccular_customize_opacity_range() {
return apply_filters(
'peccular_customize_opacity_range',
array(
'min' => 0,
'max' => 100,
'step' => 5,
)
);
}

function peccular_customize_preview_init() {
    $theme_version = wp_get_theme()->get( 'Version' );

    wp_add_inline_script(
        'peccular-customize-preview',
        sprintf(
            'wp.customize.selectiveRefresh.partialConstructor[ %1$s ].prototype.attrs = %2$s;',
            wp_json_encode( 'cover_opacity' ),
            wp_json_encode( peccular_customize_opacity_range() )
        )
    );
}
add_action( 'customize_preview_init', 'peccular_customize_preview_init' );

// for excerpt height
function peccular_customize_excerpt_length_range() {
return apply_filters(
'peccular_customize_excerpt_length_range',
array(
'min' => 0,
'max' => 100,
'step' => 5,
)
);
}

function peccular_customize_excerpt_length_init() {
    $theme_version = wp_get_theme()->get( 'Version' );

  
    wp_add_inline_script(
        'peccular-customize-preview',
        sprintf(
            'wp.customize.selectiveRefresh.partialConstructor[ %1$s ].prototype.attrs = %2$s;',
            wp_json_encode( 'excerpt_length' ),
            wp_json_encode( peccular_customize_excerpt_length_range() )
        )
    );
}

add_action( 'customize_excerpt_length_init', 'peccular_customize_excerpt_length_init' );

// for featured image height
function peccular_customize_featured_height_range() {
return apply_filters(
'peccular_customize_featured_height_range',
array(
'min' => 100,
'max' => 500,
'step' => 5,
)
);
}

function peccular_customize_featured_height_init() {
    $theme_version = wp_get_theme()->get( 'Version' );

  
    wp_add_inline_script(
        'peccular-customize-preview',
        sprintf(
            'wp.customize.selectiveRefresh.partialConstructor[ %1$s ].prototype.attrs = %2$s;',
            wp_json_encode( 'featured_img_height' ),
            wp_json_encode( peccular_customize_featured_height_range() )
        )
    );
}

add_action( 'customize_preview_featured_height_init', 'peccular_customize_featured_height_init' );

require get_parent_theme_file_path( '/inc/tab-control.php' );

// sanitize
function peccular_sanitize_choices( $input, $setting ) {
    global $wp_customize; 
    $control = $wp_customize->get_control( $setting->id ); 
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

function peccular_sanitize_checkbox( $input ) {
    return ( ( isset( $input ) && true == $input ) ? true : false );
}

function peccular_sanitize_phone_number( $phone ) {
    return preg_replace( '/[^\d+]/', '', $phone );
}

function peccular_sanitize_float( $input ) {
    return filter_var($input, FILTER_SANITIZE_NUMBER_FLOAT, FILTER_FLAG_ALLOW_FRACTION);
}


function peccular_switch_sanitization( $input ) {
    if ( true === $input ) {
        return 1;
    } else {
        return 0;
    }
}


// Integer sanitization
if ( ! function_exists( 'peccular_sanitize_integer' ) ) {
    function peccular_sanitize_integer( $input ) {
        return (int) $input;
    }
}

/* Excerpt Limit Begin */
function peccular_string_limit_words($string, $word_limit) {
    $words = explode(' ', $string, ($word_limit + 1));
    if(count($words) > $word_limit)
    array_pop($words);
    return implode(' ', $words);
}

// Change number or products per row to 3
add_filter('loop_shop_columns', 'peccular_loop_columns');
    if (!function_exists('peccular_loop_columns')) {
        function peccular_loop_columns() {
    return 3; // 3 products per row
    }
}


function peccular_sanitize_dropdown_pages( $page_id, $setting ) {
    // Ensure $input is an absolute integer.
    $page_id = absint( $page_id );
    // If $page_id is an ID of a published page, return it; otherwise, return the default.
    return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
}

// Hide show customizer options 
function peccular_shortcode_slider_enabled(){
    if(get_theme_mod('peccular_slider_section_option', 'peccular Slider Plugin') == 'Other Shortcode' ) {
        return true;
    }
    return false;
}

function peccular_shortcode_team_enabled(){
    if(get_theme_mod('peccular_team_section_option', 'peccular Team Plugin') == 'Other Shortcode' ) {
        return true;
    }
    return false;
}
function peccular_shortcode_testimonials_enabled(){
    if(get_theme_mod('peccular_testimonials_section_option', 'peccular Testimonials Plugin') == 'Other Shortcode' ) {
        return true;
    }
    return false;
}
function peccular_service_type_posts(){
    if(get_theme_mod('peccular_service_type', 'With Posts') == 'With Posts' ) {
        return true;
    }
    return false;
}

function peccular_service_type_pages(){
    if(get_theme_mod('peccular_service_type', 'With Posts') == 'With Pages' ) {
        return true;
    }
    return false;
}

function peccular_service_bg_image_opacity(){
    if(get_theme_mod('peccular_services_bg_image') != 'color' ) {
        return true;
    }
    return false;
}

function peccular_service_type_icon(){
    if(get_theme_mod('peccular_service_head_icon_enable', 'Yes') == 'Yes' ) {
        return true;
    }
    return false;
}

function peccular_about_type_icon(){
    if(get_theme_mod('peccular_about_head_icon_enable', 'Yes') == 'Yes' ) {
        return true;
    }
    return false;
}


function peccular_features_type_icon(){
    if(get_theme_mod('peccular_features_head_icon_enable', 'Yes') == 'Yes' ) {
        return true;
    }
    return false;
}

function peccular_facility_type_icon(){
    if(get_theme_mod('peccular_facility_head_icon_enable', 'Yes') == 'Yes' ) {
        return true;
    }
    return false;
}

function peccular_steps_type_icon(){
    if(get_theme_mod('peccular_steps_head_icon_enable', 'Yes') == 'Yes' ) {
        return true;
    }
    return false;
}

function peccular_blog_type_icon(){
    if(get_theme_mod('peccular_blog_head_icon_enable', 'Yes') == 'Yes' ) {
        return true;
    }
    return false;
}

function peccular_pricing_type_icon(){
    if(get_theme_mod('peccular_pricing_head_icon_enable', 'Yes') == 'Yes' ) {
        return true;
    }
    return false;
}

function peccular_newsletter_type_icon(){
    if(get_theme_mod('peccular_newsletter_head_icon_enable', 'Yes') == 'Yes' ) {
        return true;
    }
    return false;
}

function peccular_contact_type_icon(){
    if(get_theme_mod('peccular_contact_head_icon_enable', 'Yes') == 'Yes' ) {
        return true;
    }
    return false;
}

function peccular_contactinfo_type_icon(){
    if(get_theme_mod('peccular_contactinfo_head_icon_enable', 'Yes') == 'Yes' ) {
        return true;
    }
    return false;
}
function peccular_team_type_icon(){
    if(get_theme_mod('peccular_team_head_icon_enable', 'Yes') == 'Yes' ) {
        return true;
    }
    return false;
}

function peccular_testimonials_type_icon(){
    if(get_theme_mod('peccular_testimonials_head_icon_enable', 'Yes') == 'Yes' ) {
        return true;
    }
    return false;
} 

function peccular_counter_type_icon(){
    if(get_theme_mod('peccular_counter_head_icon_enable', 'Yes') == 'Yes' ) {
        return true;
    }
    return false;
}


/**
 * Function that returns if the menu is sticky
 */
if (!function_exists('bakerystore_sticky_menu')):
    function bakerystore_sticky_menu()
    {
        $is_sticky = get_theme_mod('peccular_show_sticky_header', false);

        if ($is_sticky == false):
            return 'not-sticky';
        else:
            return 'is-sticky-on';
        endif;
    }
endif;


// function peccular_header_image( $image_url ){
//     global $post;

//     if( is_singular() ){
//         $image_url      = get_the_post_thumbnail_url( $post->ID, 'full' );
//         $header_image = get_header_image();
//         $fallback_image = ! empty( $header_image ) ?  $header_image : esc_url(get_template_directory_uri()) . '/assets/images/header-default.png';
//         $image_url      = ( ! empty( $image_url) ) ? $image_url : $fallback_image;
//     }
//     return $image_url;
// }


// 1. Show plus minus buttons
  
add_action( 'woocommerce_after_quantity_input_field', 'bbloomer_display_quantity_plus' );
  
function bbloomer_display_quantity_plus() {
   echo '<button type="button" class="plus">+</button>';
}
  
add_action( 'woocommerce_before_quantity_input_field', 'bbloomer_display_quantity_minus' );
  
function bbloomer_display_quantity_minus() {
   echo '<button type="button" class="minus">-</button>';
}
  

// Single product image gallery zoom and slider

add_action( 'after_setup_theme', 'yourtheme_setup' );

function yourtheme_setup() {
    add_theme_support( 'wc-product-gallery-zoom' );
    add_theme_support( 'wc-product-gallery-lightbox' );
    add_theme_support( 'wc-product-gallery-slider' );
    add_theme_support( 'woocommerce' );
}


 add_filter( 'woocommerce_single_product_carousel_options', 'cuswoo_update_woo_flexslider_options' );
/** 
 * Filer WooCommerce Flexslider options - Add Navigation Arrows
 */
function cuswoo_update_woo_flexslider_options( $options ) {

    $options['directionNav'] = true;

    return $options;
}

//for product page read more button

// add_action( 'woocommerce_after_shop_loop_item_title', 'read_more' );

// function read_more() {
//     global $product;
//     if ( $product ) {
//         $url = esc_url( $product->get_permalink() );
//         echo '<a rel="nofollow" href="' . $url . '" class="wcproduct_read_more">View More</a>';
//     }
// }

/**
 * @snippet Edit SELECT OPTIONS Button - WordPress Shop
 */
 
add_filter( 'woocommerce_product_add_to_cart_text', 'bbloomer_change_select_options_button_text', 9999, 2 );
 
function bbloomer_change_select_options_button_text( $label, $product ) {
   if ( $product->is_type( 'variable' ) ) {
      return 'Select';
   }
   return $label;
}


//for add second feature image

add_action( 'after_setup_theme', 'custom_postimage_setup' );
function custom_postimage_setup(){
    add_action( 'add_meta_boxes', 'custom_postimage_meta_box' );
    add_action( 'save_post', 'custom_postimage_meta_box_save' );
}

function custom_postimage_meta_box(){

    //on which post types should the box appear?
    $post_types = array('Post');
    foreach($post_types as $pt){
        add_meta_box('custom_postimage_meta_box',__( 'Second Featured Image', 'peccular-premium'),'custom_postimage_meta_box_func',$pt,'side','low');
    }
}

function custom_postimage_meta_box_func($post){

    //an array with all the images (ba meta key). The same array has to be in custom_postimage_meta_box_save($post_id) as well.
    $meta_keys = array('second_featured_image');

    foreach($meta_keys as $meta_key){
        $image_meta_val=get_post_meta( $post->ID, $meta_key, true);
        ?>
        <div class="custom_postimage_wrapper" id="<?php echo $meta_key; ?>_wrapper" style="margin-bottom:20px;">
            <img src="<?php echo ($image_meta_val!=''?wp_get_attachment_image_src( $image_meta_val)[0]:''); ?>" style="width:100%;display: <?php echo ($image_meta_val!=''?'block':'none'); ?>" alt="">
            <a class="addimage button" onclick="custom_postimage_add_image('<?php echo $meta_key; ?>');"><?php _e('add image','peccular-premium'); ?></a><br>
            <a class="removeimage" style="color:#a00;cursor:pointer;display: <?php echo ($image_meta_val!=''?'block':'none'); ?>" onclick="custom_postimage_remove_image('<?php echo $meta_key; ?>');"><?php _e('remove image','peccular-premium'); ?></a>
            <input type="hidden" name="<?php echo $meta_key; ?>" id="<?php echo $meta_key; ?>" value="<?php echo $image_meta_val; ?>" />
        </div>
    <?php } ?>
    <script>
    function custom_postimage_add_image(key){

        var $wrapper = jQuery('#'+key+'_wrapper');

        custom_postimage_uploader = wp.media.frames.file_frame = wp.media({
            title: '<?php _e('select image','peccular-premium'); ?>',
            button: {
                text: '<?php _e('select image','peccular-premium'); ?>'
            },
            multiple: false
        });
        custom_postimage_uploader.on('select', function() {

            var attachment = custom_postimage_uploader.state().get('selection').first().toJSON();
            var img_url = attachment['url'];
            var img_id = attachment['id'];
            $wrapper.find('input#'+key).val(img_id);
            $wrapper.find('img').attr('src',img_url);
            $wrapper.find('img').show();
            $wrapper.find('a.removeimage').show();
        });
        custom_postimage_uploader.on('open', function(){
            var selection = custom_postimage_uploader.state().get('selection');
            var selected = $wrapper.find('input#'+key).val();
            if(selected){
                selection.add(wp.media.attachment(selected));
            }
        });
        custom_postimage_uploader.open();
        return false;
    }

    function custom_postimage_remove_image(key){
        var $wrapper = jQuery('#'+key+'_wrapper');
        $wrapper.find('input#'+key).val('');
        $wrapper.find('img').hide();
        $wrapper.find('a.removeimage').hide();
        return false;
    }
    </script>
    <?php
    wp_nonce_field( 'custom_postimage_meta_box', 'custom_postimage_meta_box_nonce' );
}

function custom_postimage_meta_box_save($post_id){

    if ( ! current_user_can( 'edit_posts', $post_id ) ){ return 'not permitted'; }

    if (isset( $_POST['custom_postimage_meta_box_nonce'] ) && wp_verify_nonce($_POST['custom_postimage_meta_box_nonce'],'custom_postimage_meta_box' )){

        //same array as in custom_postimage_meta_box_func($post)
        $meta_keys = array('second_featured_image');
        foreach($meta_keys as $meta_key){
            if(isset($_POST[$meta_key]) && intval($_POST[$meta_key])!=''){
                update_post_meta( $post_id, $meta_key, intval($_POST[$meta_key]));
            }else{
                update_post_meta( $post_id, $meta_key, '');
            }
        }
    }
}


?>